package cn.iocoder.yudao.module.bpm.controller.admin.oa.vo.reimbursement;
import cn.iocoder.yudao.module.bpm.controller.admin.oa.vo.BpmOABaseRespVO;
import cn.iocoder.yudao.module.bpm.controller.admin.upload.UploadUserFile;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;

import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.List;

@Schema(description = "管理后台 - 报销响应数据 Request VO")
@Data
@EqualsAndHashCode(callSuper = true)
@ToString(callSuper = true)
public class BpmOAReimbursementRespVO extends BpmOABaseRespVO {
    /**
     * 收款人信息
     */
    private PayeeUser payeeUser;

    @Schema(description = "报销费用归属部门ID", requiredMode = Schema.RequiredMode.REQUIRED)
    private Long belongDeptId ;

    @Schema(description = "报销项目明细", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "报销项目不能为空")
    private List<Reimbursement> reimbursements;

    @Schema(description = "报销总金额", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "报销总金额不能为空")
    private BigDecimal totalMoney ;

    @Schema(description = "报销总金额中文大写", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "报销总金额中文大写不能为空")
    private String totalMoneyChinese ;

    @Schema(description = "报销类型", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "报销类型不能为空")
    private BigDecimal reimbursementType ;

    @Schema(description = "备用金差额", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    private BigDecimal difference ;

    @Schema(description = "报销发票总数", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "报销发票总数不能为空")
    private Integer totalQuantity ;

    @Schema(description = "上传文件", requiredMode = Schema.RequiredMode.REQUIRED)
    private List<UploadUserFile> fileItems ;

    @Schema(description = "收款人信息")
    @Data
    public static class PayeeUser {

        @Schema(description = "用户编号", requiredMode = Schema.RequiredMode.REQUIRED, example = "1")
        private Long id;

        @Schema(description = "用户昵称", requiredMode = Schema.RequiredMode.REQUIRED, example = "芋艿")
        private String nickname;

        @Schema(description = "部门编号", requiredMode = Schema.RequiredMode.REQUIRED, example = "1")
        private Long deptId;

        @Schema(description = "部门名称", requiredMode = Schema.RequiredMode.REQUIRED, example = "研发部")
        private String deptName;

        @Schema(description = "电子签名", requiredMode = Schema.RequiredMode.REQUIRED, example = "http://xxx.jpg")
        private String signURL;

        @Schema(description = "用户银行卡业务表ID", requiredMode = Schema.RequiredMode.REQUIRED)
        private Long bankId;

        @Schema(description = "开户行信息", requiredMode = Schema.RequiredMode.REQUIRED)
        private String bankNName;

        @Schema(description = "银行卡号", requiredMode = Schema.RequiredMode.REQUIRED)
        private String bankNo;
    }
}
